@@ -25,11 +25,13 @@ module Gtk
                Integer, Integer)
 
     signal_new("motion_notify_event", GLib::Signal::RUN_FIRST, nil, nil,
-               Gdk::EventButton, Gtk::TreePath, Gtk::TreeViewColumn,
+               Gtk::BINDING_VERSION >= [2,0,3] ? Gdk::EventMotion : Gdk::EventButton,
+               Gtk::TreePath, Gtk::TreeViewColumn,
                Integer, Integer)
 
     signal_new("leave_notify_event", GLib::Signal::RUN_FIRST, nil, nil,
-               Gdk::EventButton, Gtk::TreePath, Gtk::TreeViewColumn,
+               Gtk::BINDING_VERSION >= [2,0,3] ? Gdk::EventCrossing : Gdk::EventButton,
+               Gtk::TreePath, Gtk::TreeViewColumn,
                Integer, Integer)
 
     signal_new("click", GLib::Signal::RUN_FIRST, nil, nil,
@@ -74,7 +76,7 @@ module Gtk
             motioned_id = @tree.get_record(motioned[0]).id rescue nil
             last_motioned_id = @tree.get_record(last_motioned[0]).id rescue nil
             if(last_motioned_id and motioned_id != last_motioned_id)
-              signal_emit("leave_notify_event", e, *last_motioned) end end
+              emit_leave_notify_from_event_motion(e, *last_motioned) end end
           last_motioned = motioned end }
 
       tree.ssc("button_press_event") { |w, e|
@@ -112,7 +114,6 @@ module Gtk
     # Messageに関連付けられた Gdk::MiraclePainter を取得する
     def miracle_painter(message)
       type_strict message => Message
-      mid = message[:id].to_s.freeze
       record = @tree.get_record_by_message(message)
       if record and record.miracle_painter
         record.miracle_painter
@@ -188,6 +189,21 @@ module Gtk
         false }
     end
 
+    # RubyGtk2 2.0.3以降は、motion_notify_eventやleave_notify_eventに
+    # 発行されるイベントが変更されている
+    if Gtk::BINDING_VERSION >= [2,0,3]
+      def emit_leave_notify_from_event_motion(e, *args)
+        signal_emit("leave_notify_event",
+                    Gdk::EventCrossing.new(Gdk::Event::LEAVE_NOTIFY).tap{ |le|
+                      le.time = e.time
+                      le.x, le.y = e.x, e.y
+                      le.x_root, le.y_root = e.x_root, e.y_root
+                      le.focus = true
+                    }, *args) end
+    else
+      def emit_leave_notify_from_event_motion(e, *args)
+        signal_emit("leave_notify_event", e, *args) end end
+
   end
 end
-# ~> -:3: undefined method `miquire' for main:Object (NoMethodError)
+
